==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/outputs/ActionIpExtendedCommunityPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.outputs

import kotlin.Suppress

/**
 * IP Extended Community Properties.
 * @property add IP Extended Community Id list properties.
 * @property delete IP Extended Community Id list properties.
 * @property set IP Extended Community Id list properties.
 */
public data class ActionIpExtendedCommunityPropertiesResponse(
    public val add: IpExtendedCommunityIdListResponse? = null,
    public val delete: IpExtendedCommunityIdListResponse? = null,
    public val `set`: IpExtendedCommunityIdListResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.managednetworkfabric.outputs.ActionIpExtendedCommunityPropertiesResponse):
            ActionIpExtendedCommunityPropertiesResponse = ActionIpExtendedCommunityPropertiesResponse(
            add = javaType.add().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            delete = javaType.delete().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            `set` = javaType.`set`().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/outputs/ActionIpExtendedCommunityPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.outputs

import kotlin.Suppress

/**
 * IP Extended Community Properties.
 * @property add IP Extended Community Id list properties.
 * @property delete IP Extended Community Id list properties.
 * @property set IP Extended Community Id list properties.
 */
public data class ActionIpExtendedCommunityPropertiesResponse(
    public val add: IpExtendedCommunityIdListResponse? = null,
    public val delete: IpExtendedCommunityIdListResponse? = null,
    public val `set`: IpExtendedCommunityIdListResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.managednetworkfabric.outputs.ActionIpExtendedCommunityPropertiesResponse): ActionIpExtendedCommunityPropertiesResponse = ActionIpExtendedCommunityPropertiesResponse(
            add = javaType.add().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            delete = javaType.delete().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            `set` = javaType.`set`().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.IpExtendedCommunityIdListResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
